import React, { useEffect, useState } from 'react';
import { View } from 'react-native';
import ScheduleDatePicker from './components/ScheduleDatePicker';
import TimeSlots from './components/TimeSlots';
import { fixedAvailableDates } from './utils/dateHelpers';
import { defaultActiveColor, defaultDayNames, defaultMonthNames, defaultTimeSlotWidth } from './utils/data';
import { LocalContext } from './components/LocalContext';
const TimeSlotPicker = _ref => {
  let {
    availableDates = fixedAvailableDates,
    setDateOfAppointment,
    scheduledAppointment,
    marginTop = 0,
    datePickerBackgroundColor,
    timeSlotsBackgroundColor,
    timeSlotsTitle,
    mainColor = defaultActiveColor,
    timeSlotWidth = defaultTimeSlotWidth,
    dayNamesOverride = defaultDayNames,
    monthNamesOverride = defaultMonthNames
  } = _ref;
  const [selectedTime, setSelectedTime] = useState('');
  const [selectedDate, setSelectedDate] = useState(availableDates[0]);
  useEffect(() => {
    var _availableDates$first;
    // Get first day with available appointments
    const firstAvailableDay = availableDates.findIndex(date => date.slotTimes.length > 0) || 0;
    setSelectedDate(availableDates === null || availableDates === void 0 ? void 0 : availableDates[firstAvailableDay]);
    setSelectedTime((availableDates === null || availableDates === void 0 || (_availableDates$first = availableDates[firstAvailableDay]) === null || _availableDates$first === void 0 || (_availableDates$first = _availableDates$first.slotTimes) === null || _availableDates$first === void 0 ? void 0 : _availableDates$first[0]) || '');
  }, [availableDates]);

  // If any changes on date and time selected update data of appointment
  useEffect(() => {
    if (selectedDate && selectedTime) {
      setDateOfAppointment({
        appointmentDate: selectedDate.date,
        appointmentTime: selectedTime
      });
    } else {
      setDateOfAppointment(null);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedDate, selectedTime]);
  return /*#__PURE__*/React.createElement(LocalContext, {
    slotDate: (selectedDate === null || selectedDate === void 0 ? void 0 : selectedDate.date) || '',
    scheduledAppointment: scheduledAppointment,
    overrideData: {
      mainColor,
      timeSlotWidth,
      dayNamesOverride,
      monthNamesOverride
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: {
      marginTop
    }
  }, /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(ScheduleDatePicker, {
    selectedDate: selectedDate,
    availableDates: availableDates,
    setSelectedDate: setSelectedDate,
    setSelectedTime: setSelectedTime,
    scheduledAppointment: scheduledAppointment,
    backgroundColor: datePickerBackgroundColor
  })), selectedDate && /*#__PURE__*/React.createElement(TimeSlots, {
    title: timeSlotsTitle,
    selectedTime: selectedTime,
    setSelectedTime: setSelectedTime,
    slotTimes: selectedDate.slotTimes,
    backgroundColor: timeSlotsBackgroundColor
  })));
};
export default TimeSlotPicker;
//# sourceMappingURL=TimeSlotPicker.js.map