import React, { useCallback, useContext, useMemo, useRef } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import ScheduleDateElement from './ScheduleDateElement';
import { theme } from '../utils/theme';
import { OverrideDataContext } from './LocalContext';
const today = new Date();
const currentDay = today.getDate();
const ScheduleDatePicker = _ref => {
  let {
    availableDates,
    selectedDate,
    setSelectedDate,
    setSelectedTime,
    scheduledAppointment,
    backgroundColor = theme.colors.white
  } = _ref;
  const scrollRef = useRef();
  const {
    monthNamesOverride
  } = useContext(OverrideDataContext);
  const currentMonth = useMemo(() => monthNamesOverride[today.getMonth()], [monthNamesOverride]);
  const getScheduledAppointmentDate = useCallback(date => new Date(date).getDate(), []);
  const onDatePress = date => {
    var _date$slotTimes;
    setSelectedDate(date);
    setSelectedTime((date === null || date === void 0 || (_date$slotTimes = date.slotTimes) === null || _date$slotTimes === void 0 ? void 0 : _date$slotTimes[0]) || '');
  };
  const getAppointmentDay = useCallback(() => {
    if (scheduledAppointment !== null && scheduledAppointment !== void 0 && scheduledAppointment.appointmentDate) {
      return getScheduledAppointmentDate(scheduledAppointment === null || scheduledAppointment === void 0 ? void 0 : scheduledAppointment.appointmentDate);
    }
    return -1;
  }, [scheduledAppointment === null || scheduledAppointment === void 0 ? void 0 : scheduledAppointment.appointmentDate, getScheduledAppointmentDate]);
  const dateContainer = (date, index) => {
    return /*#__PURE__*/React.createElement(View, {
      key: index
    }, /*#__PURE__*/React.createElement(ScheduleDateElement, {
      slotDate: date,
      selectedDate: selectedDate,
      onPress: () => {
        onDatePress(date);
      },
      currentDay: currentDay,
      appointmentDay: getAppointmentDay()
    }));
  };
  const getDates = () => {
    return availableDates.map((data, index) => {
      return dateContainer(data, index);
    });
  };
  return /*#__PURE__*/React.createElement(View, {
    style: {
      backgroundColor
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.title
  }, currentMonth, " ", currentDay)), /*#__PURE__*/React.createElement(ScrollView, {
    ref: scrollRef,
    showsHorizontalScrollIndicator: false,
    horizontal: true,
    contentContainerStyle: styles.scrollViewContent
  }, getDates()));
};
const styles = StyleSheet.create({
  container: {
    paddingHorizontal: theme.spacing.m,
    marginBottom: theme.spacing.m
  },
  title: {
    color: theme.colors.primary900,
    fontSize: 22,
    lineHeight: 28,
    fontWeight: '700'
  },
  scrollViewContent: {
    paddingHorizontal: theme.spacing.m
  }
});
export default ScheduleDatePicker;
//# sourceMappingURL=ScheduleDatePicker.js.map