import React, { useCallback, useContext, useMemo } from 'react';
import { StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import { theme } from '../utils/theme';
import { OverrideDataContext, ScheduledAppointmentContext, SelectedDateContext } from './LocalContext';
const TimeSlot = _ref => {
  let {
    value,
    onPress,
    selectedTime
  } = _ref;
  const isSelected = selectedTime === value;
  const scheduledAppointment = useContext(ScheduledAppointmentContext);
  const selectedDate = useContext(SelectedDateContext);
  const {
    mainColor,
    timeSlotWidth
  } = useContext(OverrideDataContext);
  const appointmentDateToCompare = useMemo(() => {
    var _scheduledAppointment;
    return scheduledAppointment === null || scheduledAppointment === void 0 || (_scheduledAppointment = scheduledAppointment.appointmentDate) === null || _scheduledAppointment === void 0 ? void 0 : _scheduledAppointment.split('T')[0];
  }, [scheduledAppointment === null || scheduledAppointment === void 0 ? void 0 : scheduledAppointment.appointmentDate]);
  const selectedDateToCompare = useMemo(() => selectedDate.split('T')[0], [selectedDate]);
  const appointmentDot = useMemo(() => {
    return /*#__PURE__*/React.createElement(View, {
      style: [styles.todayDot, isSelected ? styles.todayBackground : {
        backgroundColor: mainColor
      }]
    });
  }, [isSelected, mainColor]);

  // Check if there is an appointment to mark time slot appropriately
  const getAppointmentDot = useCallback(() => {
    if (scheduledAppointment !== null && scheduledAppointment !== void 0 && scheduledAppointment.appointmentDate) {
      if (selectedDateToCompare === appointmentDateToCompare && scheduledAppointment.appointmentTime === value) {
        return appointmentDot;
      }
    }
    return null;
  }, [appointmentDot, scheduledAppointment, appointmentDateToCompare, selectedDateToCompare, value]);
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onPress
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.container, {
      width: timeSlotWidth
    }, isSelected ? {
      backgroundColor: mainColor
    } : styles.unSelected]
  }, /*#__PURE__*/React.createElement(Text, {
    style: [isSelected ? styles.selectedText : styles.unSelectedText]
  }, value), getAppointmentDot()));
};
const styles = StyleSheet.create({
  container: {
    height: 36,
    alignItems: 'center',
    justifyContent: 'center',
    borderRadius: theme.borderRadii.ml
  },
  unSelected: {
    backgroundColor: theme.colors.primary200
  },
  selectedText: {
    color: theme.colors.white,
    fontSize: 14,
    lineHeight: 20,
    fontWeight: '600'
  },
  unSelectedText: {
    color: theme.colors.primary900,
    fontSize: 15,
    lineHeight: 20,
    fontWeight: '400'
  },
  todayBackground: {
    backgroundColor: theme.colors.primary200
  },
  todayDot: {
    position: 'absolute',
    bottom: 4,
    width: 6,
    height: 6,
    borderRadius: theme.borderRadii.l
  }
});
export default TimeSlot;
//# sourceMappingURL=TimeSlot.js.map